
---
# DIGI POT 14 click

> PRVIH_PAR_RECENICA_SA_PRODUCT_PAGE_DA_ISPRATE_CELINU

<p align="center">
  <img src="CLICK_IMAGE_LINK" height=300px>
</p>

[click Product page](CLICK_PRODUCT_PAGE_LINK)

---


#### Click library

- **Author**        : Stefan Ilic
- **Date**          : Aug 2023.
- **Type**          : I2C type


# Software Support

We provide a library for the DIGI POT 14 Click
as well as a demo application (example), developed using MikroElektronika
[compilers](https://www.mikroe.com/necto-studio).
The demo can run on all the main MikroElektronika [development boards](https://www.mikroe.com/development-boards).

Package can be downloaded/installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

## Library Description

> This library contains API for DIGI POT 14 Click driver.

#### Standard key functions :

- `digipot14_cfg_setup` Config Object Initialization function.
```c
void digipot14_cfg_setup ( digipot14_cfg_t *cfg );
```

- `digipot14_init` Initialization function.
```c
err_t digipot14_init ( digipot14_t *ctx, digipot14_cfg_t *cfg );
```

- `digipot14_default_cfg` Click Default Configuration function.
```c
err_t digipot14_default_cfg ( digipot14_t *ctx );
```

#### Example key functions :

- `digipot14_reg_write` DIGI POT 14 register write function.
```c
err_t digipot14_reg_write ( digipot14_t *ctx, uint8_t reg, uint8_t data_in );
```

- `digipot14_set_pot_a_res` DIGI POT 14 set the resistance of potentiometer A function.
```c
err_t digipot14_set_pot_a_res ( digipot14_t *ctx, uint8_t resistance );
```

- `digipot14_set_pot_b_res` DIGI POT 14 set the resistance of potentiometer B function.
```c
err_t digipot14_set_pot_b_res ( digipot14_t *ctx, uint8_t resistance );
```

## Example Description

> This library contains API for DIGI POT 14 Click driver.
  The demo application uses a digital potentiometer 
  to change the resistance values.

**The demo application is composed of two sections :**

### Application Init

> The initialization of I2C module, log UART, and additional pins.
  After the driver init, the app executes a default configuration.

```c

void application_init ( void ) 
{
    log_cfg_t log_cfg;  /**< Logger config object. */
    digipot14_cfg_t digipot14_cfg;  /**< Click config object. */

    /** 
     * Logger initialization.
     * Default baud rate: 115200
     * Default log level: LOG_LEVEL_DEBUG
     * @note If USB_UART_RX and USB_UART_TX 
     * are defined as HAL_PIN_NC, you will 
     * need to define them manually for log to work. 
     * See @b LOG_MAP_USB_UART macro definition for detailed explanation.
     */
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, " Application Init " );

    // Click initialization.
    digipot14_cfg_setup( &digipot14_cfg );
    DIGIPOT14_MAP_MIKROBUS( digipot14_cfg, MIKROBUS_1 );
    if ( I2C_MASTER_ERROR == digipot14_init( &digipot14, &digipot14_cfg ) ) 
    {
        log_error( &logger, " Communication init." );
        for ( ; ; );
    }
    
    if ( DIGIPOT14_ERROR == digipot14_default_cfg ( &digipot14 ) )
    {
        log_error( &logger, " Default configuration." );
        for ( ; ; );
    }
    
    log_info( &logger, " Application Task " );
}

```

### Application Task

> This example demonstrates the use of the DIGI POT 14 Click board™.
  The demo application iterates through the entire wiper range and 
  sets the resistance in steps of approximately 10 kOhm.
  Results are being sent to the UART Terminal, where you can track their changes.

```c
void application_task ( void ) 
{
    for ( uint8_t res_val = 0; res_val <= 100; res_val += 10 )
    {
        log_printf( &logger, " Resistance = %d KOhm \r\n", res_val );
        digipot14_set_pot_b_res( &digipot14, res_val );
        digipot14_set_pot_a_res( &digipot14, res_val );
        Delay_ms( 5000 );
    }
}
```


The full application code, and ready to use projects can be installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

**Other Mikroe Libraries used in the example:**

- MikroSDK.Board
- MikroSDK.Log
- Click.DIGIPOT14

**Additional notes and informations**

Depending on the development board you are using, you may need
[USB UART click](https://www.mikroe.com/usb-uart-click),
[USB UART 2 Click](https://www.mikroe.com/usb-uart-2-click) or
[RS232 Click](https://www.mikroe.com/rs232-click) to connect to your PC, for
development systems with no UART to USB interface available on the board. UART
terminal is available in all MikroElektronika
[compilers](https://shop.mikroe.com/compilers).

---
